@@ -41,8 +41,6 @@
 
 #define KCONTACTS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KCONTACTS_NO_DEPRECATED) && !defined(KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KCONTACTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCONTACTS_NO_DEPRECATED
-#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KCONTACTS_NO_DEPRECATED_WARNINGS
 #  define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCONTACTS_DEPRECATED_WARNINGS_SINCE KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KCONTACTS_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KCONTACTS_DEPRECATED
-#  define KCONTACTS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KCONTACTS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KCONTACTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KCONTACTS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
